==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/infrastructure/model/WrapperBlockStateModel.java <==
package com.zurrtum.create.client.infrastructure.model;

import com.zurrtum.create.client.compat.fabric.WrapperModel;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_10889;
import net.minecraft.class_1920;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_5819;
import net.minecraft.class_7775;
import java.util.List;
import java.util.function.Function;

public abstract class WrapperBlockStateModel implements class_1087, class_1087.class_9979 {
    private static final boolean FABRIC = FabricLoader.getInstance().isModLoaded("fabric-model-loading-api-v1");
    protected class_1087 model;
    protected Function<class_7775, class_1087> bake;

    public WrapperBlockStateModel() {
    }

    public WrapperBlockStateModel(class_2680 state, class_9979 unbaked) {
        bake = baker -> unbaked.method_65542(state, baker);
    }

    public void addPartsWithInfo(class_1920 world, class_2338 pos, class_2680 state, class_5819 random, List<class_10889> parts) {
        method_68513(random, parts);
    }

    @Override
    public void method_68513(class_5819 random, List<class_10889> parts) {
        model.method_68513(random, parts);
    }

    public class_1058 particleSpriteWithInfo(class_1920 world, class_2338 pos, class_2680 state) {
        return method_68511();
    }

    @Override
    public class_1058 method_68511() {
        return model.method_68511();
    }

    @Override
    public class_1087 method_65542(class_2680 state, class_7775 baker) {
        if (bake != null) {
            model = bake.apply(baker);
            bake = null;
        }
        return this;
    }

    @Override
    public void method_62326(class_10103 resolver) {
    }

    @Override
    public Object method_62332(class_2680 state) {
        return this;
    }

    public static class_1087 unwrapCompat(class_1087 model) {
        if (FABRIC && model instanceof WrapperModel wrapper) {
            return wrapper.create$getWrapped();
        }
        return model;
    }
}

==> create-fly-1.21.11-pre1-6.0.8-1-sources.jar: com/zurrtum/create/client/infrastructure/model/WrapperBlockStateModel.java <==
package com.zurrtum.create.client.infrastructure.model;

import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_10889;
import net.minecraft.class_1920;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_5819;
import net.minecraft.class_7775;
import java.util.List;
import java.util.function.Function;

public abstract class WrapperBlockStateModel implements class_1087, class_1087.class_9979 {
    private static final boolean FABRIC = FabricLoader.getInstance().isModLoaded("fabric-model-loading-api-v1");
    protected class_1087 model;
    protected Function<class_7775, class_1087> bake;

    public WrapperBlockStateModel() {
    }

    public WrapperBlockStateModel(class_2680 state, class_9979 unbaked) {
        bake = baker -> unbaked.method_65542(state, baker);
    }

    public void addPartsWithInfo(class_1920 world, class_2338 pos, class_2680 state, class_5819 random, List<class_10889> parts) {
        method_68513(random, parts);
    }

    @Override
    public void method_68513(class_5819 random, List<class_10889> parts) {
        model.method_68513(random, parts);
    }

    public class_1058 particleSpriteWithInfo(class_1920 world, class_2338 pos, class_2680 state) {
        return method_68511();
    }

    @Override
    public class_1058 method_68511() {
        return model.method_68511();
    }

    @Override
    public class_1087 method_65542(class_2680 state, class_7775 baker) {
        if (bake != null) {
            model = bake.apply(baker);
            bake = null;
        }
        return this;
    }

    @Override
    public void method_62326(class_10103 resolver) {
    }

    @Override
    public Object method_62332(class_2680 state) {
        return this;
    }

    public static class_1087 unwrapCompat(class_1087 model) {
        //        if (FABRIC && model instanceof WrapperModel wrapper) {
        //            return wrapper.create$getWrapped();
        //        }
        return model;
    }
}
